@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION $ALLSQL $SECTIONID);
-$VERSION = '5.05';
+$VERSION = '5.06';
 
 =head1 NAME
 
@@ -12,7 +12,8 @@ Labyrinth::Plugin::Articles::Sections - Sections handler plugin for Labyrinth
 
 =head1 DESCRIPTION
 
-Contains all the section handling functionality
+Contains all the section handling functionality for the Labyrinth
+framework.
 
 =cut
 
@@ -134,7 +135,7 @@ __END__
 
 =head1 SEE ALSO
 
-  Labyrinth
+L<Labyrinth>
 
 =head1 AUTHOR
 
@@ -147,6 +148,6 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
-  modify it under the same terms as Perl itself.
+  modify it under the Artistic License 2.0.
 
 =cut
