@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Folders;
 use warnings;
 use strict;
 
-my $VERSION = '5.05';
+my $VERSION = '5.06';
 
 =head1 NAME
 
@@ -11,7 +11,8 @@ Labyrinth::Plugin::Folders - handler for Labyrinth folders
 
 =head1 DESCRIPTION
 
-Contains all the folders handling functionality
+Contains all the folder handling functionality for the Labyrinth
+framework.
 
 =cut
 
@@ -161,7 +162,7 @@ __END__
 
 =head1 SEE ALSO
 
-  Labyrinth
+L<Labyrinth>
 
 =head1 AUTHOR
 
@@ -174,6 +175,6 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
-  modify it under the same terms as Perl itself.
+  modify it under the Artistic License 2.0.
 
 =cut
