@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Inbox;
 use warnings;
 use strict;
 
-my $VERSION = '5.05';
+my $VERSION = '5.06';
 
 =head1 NAME
 
@@ -11,7 +11,8 @@ Labyrinth::Plugin::Inbox - Inbox plugin handler for Labyrinth
 
 =head1 DESCRIPTION
 
-Contains all the inbox/message handling functionality
+Contains all the inbox/message handling functionality for the Labyrinth
+framework.
 
 =cut
 
@@ -86,7 +87,7 @@ __END__
 
 =head1 SEE ALSO
 
-  Labyrinth
+L<Labyrinth>
 
 =head1 AUTHOR
 
@@ -99,6 +100,6 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
-  modify it under the same terms as Perl itself.
+  modify it under the Artistic License 2.0.
 
 =cut
