@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Menus;
 use warnings;
 use strict;
 
-my $VERSION = '5.05';
+my $VERSION = '5.06';
 
 =head1 NAME
 
@@ -11,7 +11,8 @@ Labyrinth::Plugin::Menus - Plugin Menus handler for Labyrinth
 
 =head1 DESCRIPTION
 
-Contains all the menus handling functionality
+Contains all the menu handling functionality for the Labyrinth
+framework.
 
 =cut
 
@@ -454,7 +455,7 @@ __END__
 
 =head1 SEE ALSO
 
-  Labyrinth
+L<Labyrinth>
 
 =head1 AUTHOR
 
@@ -467,6 +468,6 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
-  modify it under the same terms as Perl itself.
+  modify it under the Artistic License 2.0.
 
 =cut
