@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Users::Info;
 use warnings;
 use strict;
 
-my $VERSION = '5.05';
+my $VERSION = '5.06';
 
 =head1 NAME
 
@@ -11,7 +11,8 @@ Labyrinth::Plugin::Users::Info - Additional Users Info handler for Labyrinth
 
 =head1 DESCRIPTION
 
-Contains all the extra user info handling functionality
+Contains all the additional user info handling functionality for the Labyrinth
+framework.
 
 =cut
 
@@ -165,7 +166,7 @@ __END__
 
 =head1 SEE ALSO
 
-  Labyrinth
+L<Labyrinth>
 
 =head1 AUTHOR
 
@@ -178,6 +179,6 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
-  modify it under the same terms as Perl itself.
+  modify it under the Artistic License 2.0.
 
 =cut
